
********************************************************************
*     Replicating Schmidt-Catran/Spiess, ASR 2016 (SCS)
*       Katrin Auspurg, Josef Brüderl & Thomas Woehler
*            Last update: November 15, 2018	
*                  ROR LEVEL ANALYSIS
********************************************************************

* Based on syntax and regional data kindly made available by SCS!


version 15.0
set more off
capture log close

* Defining paths (adapt to your system!)
local path "    "                                   // your main  path
global adata 	`""`path'\Allbus""'       		    // Allbus Data
global data 	`""`path'\ROR\Data""'        	    // Working directory  
global output	`""`path'\ROR\Output""'  	        // Output directory

* Opening Log-File
cd $output
log using 2_Descriptives.log, replace


* Opening data
cd $data
use data_complete, clear
* We do not use "data_complete_largeN", because we want to follow SCS closely

* Here we drop Berlin, because we are on the regional level and Berlin includes both West and East
keep if berlin ~= 1

*****************************************************************************
** Figure 2: Mean Welfare attitudes by Share of Foreigners and East/West 
*****************************************************************************

*** Aggregating welfare attitudes

* Support of extension
gen                       ext       =   morewel == 3 
bysort region year: egen  mean_ext  =   mean(ext)
replace                   mean_ext  =   mean_ext * 100    // in percent
sum mean_ext     if  nr == 1

* Support of cut
gen                       cut       =   morewel == 1
bysort region year: egen  mean_cut  =   mean(cut)
replace                   mean_cut  =   mean_cut * 100    // in percent
sum mean_cut     if  nr == 1

 
cd $output

graph twoway     ///  Figure 2
  (lpolyci mean_ext foreign if west == 0               , clcolor(gs4))                                       /// East
  (scatter mean_ext foreign if west == 0 & year == 1994, mcolor(gs6) msize(medium) msymbol(circle))          ///
  (scatter mean_ext foreign if west == 0 & year >  1994, mcolor(gs6) msize(medium) msymbol(circle_hollow))   ///
  (lpolyci mean_ext foreign if west == 1               , clcolor(gs4))                                       /// West
  (scatter mean_ext foreign if west == 1 & year == 1994, mcolor(gs6) msize(medium) msymbol(triangle))        ///
  (scatter mean_ext foreign if west == 1 & year >  1994, mcolor(gs6) msize(medium) msymbol(triangle_hollow)) ///
       if  nr == 1,                                                                                          /// applies to all graphs
  xlabels(0(2)18)     xtitle("Proportion foreigners (%)", margin(0 0 0 2) size(mlarge))                      /// Graph options
  ylabels(0(20)80, grid angle(0))                                                                            ///
  ytitle("Resp. in favor of increasing welfare (%)", margin(0 2 0 0) size(mlarge))                           ///
  legend(label(1 "95% CI") label(2 "local polynomial smoothing") label(3 "Eastern Germany, 1994")            ///
  label(4 "Eastern Germany, 2000-2010") label(7 "Western Germany, 1994") label(8 "Western Germany, 2000-2010")) ///
  legend(order(3 7 4 8 2 1 ) size(small)) ysize(5) xsize(7) saving(Figure2, replace)

graph export Figure2.png, replace width(10000)



graph twoway     ///  Figure 2 (simple version)
  (scatter mean_ext foreign, mcolor(gs6) msize(medium) msymbol(circle))                     ///
         if  nr == 1,                                                                       /// applies to all graphs
  xlabels(0(2)18)     xtitle("Proportion foreigners (%)", margin(0 0 0 2) size(mlarge))     /// Graph options
  ylabels(0(20)80, grid angle(0))                                                           ///
  ytitle("Resp. in favor of increasing welfare (%)", margin(0 2 0 0) size(mlarge))          ///
  ysize(5) xsize(7) saving(Figure2simple, replace)
  
graph export Figure2simple.png, replace width(10000)



**************************************************************************************************
log close
