
********************************************************************
*     Replicating Schmidt-Catran/Spiess, ASR 2016 (SCS)
*       Katrin Auspurg, Josef Brüderl & Thomas Woehler
*            Last update: October 23, 2018	
*                  STATE LEVEL ANALYSIS
********************************************************************

* Based on syntax and regional data kindly made available by SCS!


version 15.0
set more off
capture log close

* Defining paths (adapt to your system!)
local path "    "                                   // your main  path
global adata 	`""`path'\Allbus""'       		    // Allbus Data
global data 	`""`path'\Laender\Data""'        	// Working directory  
global output	`""`path'\Laender\Output""'  	    // Output directory

* Opening Log-File
cd $output
log using 2_Descriptives.log, replace


* Opening data
cd $data
use data_complete, clear
cd $output


*****************************************************************************
* Frequencies outcome variable
*****************************************************************************
tab1 v205 v206


*****************************************************************************
* Aggregating welfare attitudes
*****************************************************************************
gen                       ext       =   morewel == 3 
bysort region year: egen  mean_ext  =   mean(ext)
replace                   mean_ext  =   mean_ext * 100    // in percent
sum mean_ext     if  nr == 1


*****************************************************************************
** Figure 2: Mean Welfare attitudes by Share of Foreigners and East/West 
*****************************************************************************

preserve   
keep if berlin ~= 1 // Here we drop Berlin, because we are on the regional level and Berlin includes both West and East
keep if n_cases > 9 // Here we follow SCS in using only regional units with n>9


graph twoway     ///  Figure 2 (simple Scatterplot)
  (lpolyci mean_ext foreign, clcolor(gs4))                                                  /// 
  (scatter mean_ext foreign, mcolor(gs6) msize(medium) msymbol(circle))                     ///
         if  nr == 1,                                                                       /// applies to all graphs
  xlabels(0(2)16)     xtitle("Proportion foreigners (%)", margin(0 0 0 2) size(mlarge))     /// Graph options
  ylabels(0(20)80, grid angle(0))                                                           ///
  ytitle("Resp. in favor of increasing welfare (%)", margin(0 2 0 0) size(mlarge))          ///
  legend(label(1 "95% CI") label(2 "local polynomial smoothing")) legend(order(2 1) size(small))  ///
  title("Bivariate Scatterplot") ///
  ysize(5) xsize(7) saving("Figure 2a", replace)


graph twoway     ///  Figure 2 (separate for East/West)
  (lpolyci mean_ext foreign if west == 0               , clcolor(gs4))                                       /// East
  (scatter mean_ext foreign if west == 0 & year == 1994, mcolor(gs6) msize(medium) msymbol(circle))          ///
  (scatter mean_ext foreign if west == 0 & year >  1994, mcolor(gs6) msize(medium) msymbol(circle_hollow))   ///
  (lpolyci mean_ext foreign if west == 1               , clcolor(gs4))                                       /// West
  (scatter mean_ext foreign if west == 1 & year == 1994, mcolor(gs6) msize(medium) msymbol(triangle))        ///
  (scatter mean_ext foreign if west == 1 & year >  1994, mcolor(gs6) msize(medium) msymbol(triangle_hollow)) ///
       if  nr == 1,                                                                                          /// applies to all graphs
  xlabels(0(2)16)     xtitle("Proportion foreigners (%)", margin(0 0 0 2) size(mlarge))                      /// Graph options
  ylabels(0(20)80, grid angle(0))                                                                            ///
  ytitle("Resp. in favor of increasing welfare (%)", margin(0 2 0 0) size(mlarge))                           ///
  legend(label(1 "95% CI") label(2 "local polynomial smoothing") label(3 "Eastern Germany, 1994")            ///
  label(4 "Eastern Germany, 2000-2010") label(7 "Western Germany, 1994") label(8 "Western Germany, 2000-2010")) legend(order(3 7 4 8 2 1 ) size(small)) ///
  title("Scatterplot Separate for East/West") ///
  ysize(5) xsize(7) saving("Figure 2b", replace)

  
 graph twoway     ///  Figure 2 (w/o 1994)
  (lpolyci mean_ext foreign if west == 0, clcolor(gs4))                                       /// East
  (scatter mean_ext foreign if west == 0, mcolor(gs6) msize(medium) msymbol(circle_hollow))   ///
  (lpolyci mean_ext foreign if west == 1, clcolor(gs4))                                       /// West
  (scatter mean_ext foreign if west == 1, mcolor(gs6) msize(medium) msymbol(triangle_hollow)) ///
       if  nr == 1 & year > 1994,                                                             /// applies to all graphs
  xlabels(0(2)16)     xtitle("Proportion foreigners (%)", margin(0 0 0 2) size(mlarge))       /// Graph options
  ylabels(0(20)80, grid angle(0))                                                             ///
  ytitle("Resp. in favor of increasing welfare (%)", margin(0 2 0 0) size(mlarge))            ///
  legend(label(1 "95% CI") label(2 "local polynomial smoothing") label(3 "Eastern Germany")   ///
  label(6 "Western Germany") )     legend(order(3 6 2 1 ) size(small))                        ///
  title("Scatterplot Separate for East/West w/o 1994") ///
  ysize(5) xsize(7) saving("Figure 2c", replace)

  
restore



********************************************************************************
** Figure 1: Attidues by survey year for Western and Eastern Germany
********************************************************************************

bysort east: tab morewel year if berlin ~= 1, col   // in Table format

* Generate variables showing mean welfare attitudes by survey year & West-East
tab morewel, gen(morewel_)
egen mean_morewel_1w = mean(morewel_1) if east == 0 & berlin ~= 1, by(year)  //welfare should be cut, west
egen mean_morewel_2w = mean(morewel_2) if east == 0 & berlin ~= 1, by(year)  // should by kept the same
egen mean_morewel_3w = mean(morewel_3) if east == 0 & berlin ~= 1, by(year)  // should be extended
egen mean_morewel_1e = mean(morewel_1) if east == 1 & berlin ~= 1, by(year)  //welfare should be cut, east
egen mean_morewel_2e = mean(morewel_2) if east == 1 & berlin ~= 1, by(year)  // should by kept the same
egen mean_morewel_3e = mean(morewel_3) if east == 1 & berlin ~= 1, by(year)  // should be extended

replace mean_morewel_1w = mean_morewel_1w * 100  // to get proportions
replace mean_morewel_2w = mean_morewel_2w * 100  
replace mean_morewel_3w = mean_morewel_3w * 100  
replace mean_morewel_1e = mean_morewel_1e * 100  
replace mean_morewel_2e = mean_morewel_2e * 100  
replace mean_morewel_3e = mean_morewel_3e * 100  

* West
twoway (scatter mean_morewel_1w year, msymbol(circle_hollow)   mlcolor(gs6)  c(l) sort) ///
       (scatter mean_morewel_2w year, msymbol(triangle_hollow) mlcolor(gs10) c(l) sort) ///
       (scatter mean_morewel_3w year, msymbol(circle)          mlcolor(gs04) c(l) sort), ///
  legend (size(medium) label(1 "resp. in favor of decreasing") label(2 "resp. in favor of keeping") label(3 "resp. in favor of increasing"))  ///
  xlabel(1994 2000 2004 2010) xtitle("Survey Year", size(large)) title("Western Germany") ///
  name(morewel_w, replace) ylabel(0 "0%" 20"20%" 40"40%" 60"60%" 80"80%", grid angle(0))

* East
twoway (scatter mean_morewel_1e year, msymbol(circle_hollow)   mlcolor(gs6)  c(l) sort) ///
       (scatter mean_morewel_2e year, msymbol(triangle_hollow) mlcolor(gs10) c(l) sort) ///
       (scatter mean_morewel_3e year, msymbol(circle)          mlcolor(gs04) c(l) sort), ///
  legend (size(medium) label(1 "resp. in favor of decreasing") label(2 "resp. in favor of keeping") label(3 "resp. in favor of increasing"))  ///
  xlabel(1994 2000 2004 2010) xtitle("Survey Year", size(large)) title("Eastern Germany") ///
  name(morewel_e, replace) ylabel(0 "0%" 20"20%" 40"40%" 60"60%" 80"80%", grid angle(0))

grc1leg morewel_w morewel_e, legendfrom(morewel_e) saving("Figure 1", replace)


*************************************************************************************
* Figure: Heterogeneous welfare attitude trends ("morewel" treated as metric variable)
*************************************************************************************

recode morewel (1=-1)(2=0)(3=1), gen(morewel_rec)  //center around zero

egen mean_morewel_w = mean(morewel_rec) if east == 0 & berlin ~= 1, by(year)
egen mean_morewel_e = mean(morewel_rec) if east == 1 & berlin ~= 1, by(year)

* Bivariate
twoway (scatter mean_morewel_w year, msymbol(triangle) mcolor(gs10) msize(medlarge) mlcolor(gs10) c(l) sort)  ///
       (scatter mean_morewel_e year, msymbol(circle)   mcolor(gs6)  msize(medlarge) mlcolor(gs6)  c(l) sort), ///
       legend (size(medium) label(1 "Western Germany") label(2 "Eastern Germany") )  ///
       xlabel(1994 2000 2004 2010) xtitle("Survey Year", size(large))  ///
       ylabel(-1(.2)1, grid gmin angle(0))

* Multivariate
reg morewel_rec male age married primary higher_secondary employed unemployed leftright income_hh_equiv i.comsize  ///
  foreign_m foreign_dm unemplr_m unemplr_dm gdppc_m gdppc_dm i.east##i.year
margins year, over(east)
marginsplot


********************************************************************************
* Figure A1 OS: Unemployment rates 
********************************************************************************

egen mean_unempl_w = mean(unemplr) if east == 0 & berlin ~= 1 & nr == 1, by(year)
egen mean_unempl_e = mean(unemplr) if east == 1 & berlin ~= 1 & nr == 1, by(year)

twoway (scatter mean_unempl_w year, msymbol(triangle) mcolor(gs10) msize(medlarge) mlcolor(gs10) c(l) sort)  ///
       (scatter mean_unempl_e year, msymbol(circle)   mcolor(gs6)  msize(medlarge) mlcolor(gs6)  c(l) sort),  ///
  legend (size(medium) label(1 "Western Germany") label(2 "Eastern Germany") )  ///
  xlabel(1994 2000 2004 2010) xtitle("Survey Year", size(large)) ///
  ylabel(0"0%" 5"5%" 10"10%" 15"15%" 20"20%" 25"25%", grid gmin angle(0)) saving("Figure A1", replace)



***************************************************************************
* Figure D1 OS: Figures by federal states 
***************************************************************************

** predicted residuals from regressions with individual level only (no context variables); only east west
reg morewel male age married primary higher_secondary employed unemployed leftright income_hh_equiv  ///
   , vce(cluster region)
predict resid, resid
bysort id_bdl year: egen mean_resid = mean(resid)

* sort federal states by share of foreigners
gen foreign_mhelp = foreign_m 
replace foreign_mhelp =. if id_bdl ==10 
sort foreign_mhelp 
xtile id_newhelp = foreign_mhelp if nr == 1, nquantiles(15)  
bysort id_bdl: egen id_new = min(id_newhelp)
* fre id_new
* bysort id_new: fre id_bdl
drop id_newhel foreign_mhelp 

set graphics off
foreach num of numlist 1/15 {
 quietly twoway (lfit mean_resid foreign_dm, lcolor(red)) ///
 (scatter mean_resid foreign_dm if year == 1994, mcolor(gs2) msize(medium) msymbol(circle_hollow)) ///  
 (scatter mean_resid foreign_dm if year == 2000, mcolor(gs5) msize(medium) msymbol(triangle)) /// 
 (scatter mean_resid foreign_dm if year == 2004, mcolor(gs7) msize(medium) msymbol(square)) /// 
 (scatter mean_resid foreign_dm if year == 2010, mcolor(gs10) msize(medium) msymbol(diamond)) /// 
 if nr == 1 & id_new ==`num', ///
 xscale(r(-1(0.2)1)) xlabels(-1(0.2)1) yscale(r(-0.7(0.1)0.5)) ylabels(-0.7(0.1)0.5) ///
 legend(order (2 3 4 5) lab(2 "1994") lab(3 "2000") lab(4 "2004") lab(5 "2010")) ///
 title(`num', position(6)) xtitle("") name(g_`num', replace)
}
set graphics on

grc1leg g_1 g_2 g_3 g_4 g_5 ///
    g_6 g_7 g_8 g_9 g_10 g_11 g_12 g_13 g_14 g_15, rows(3) cols(5) name(figure_3_fedstates, replace) ///
    legendfrom(g_1) imargin(0 0 4 4) saving("Figure D1", replace)


  
*********************************************************************************
** Table A1: Mean proportion foreigners, attitudes, and unemployment rates by federal states & year 
*********************************************************************************

* share foreigners // if nr ==1 to select only one observation / not bias mean values by number of cases
bysort year: tabstat foreign if west == 0 & nr == 1, by(id_bdl) stats(mean n)
tabstat foreign if west == 0 & nr == 1, by(id_bdl) stats(mean n)
bysort year: tabstat foreign if id_bdl ~=10 & nr == 1, by(west) stats(mean n)
bysort west: sum foreign if id_bdl ~= 10 & nr == 1
bysort year: tabstat foreign if west == 1 & nr == 1, by(id_bdl) stats(mean n)
tabstat foreign if west == 1 & nr == 1, by(id_bdl) stats(mean n)
tabstat foreign if id_bdl ==10 & nr == 1, by(year) stats(mean n)

* attitudes 
bysort year: tabstat ext if west == 0, by(id_bdl) stats(mean n)
tabstat ext if west == 0, by(id_bdl) stats(mean n)
bysort west: sum ext if id_bdl ~= 10
bysort year: tabstat ext if west == 1, by(id_bdl) stats(mean n)
tabstat ext if west == 1, by(id_bdl) stats(mean n)
bysort year: tabstat ext if id_bdl ~=10, by(west) 
tabstat ext if id_bdl ==10, by(year)

* Proportion unemployed // if nr == 1 to select only one observation / not bias mean values by number of cases
bysort year: tabstat unemplr if west == 0 & nr == 1, by(id_bdl) stats(mean n)
tabstat unemplr if west == 0 & nr == 1, by(id_bdl) stats(mean n)
bysort year: tabstat unemplr if id_bdl ~=10 & nr == 1, by(west) stats(mean n)
bysort west: sum unemplr if id_bdl ~= 10 & nr == 1
tabstat unemplr if west == 1 & nr == 1, by(id_bdl) stats(mean n)
bysort year: tabstat unemplr if west == 1 & nr == 1, by(id_bdl) stats(mean n)
tabstat unemplr if id_bdl ==10 & nr == 1, by(year)


*****************************************************************************
* Is there a heterogeneous time trend also with "morewel_smallN" ?
*****************************************************************************
drop morewel_*
tab morewel_smallN, gen(morewel_)
egen mean_morewel_1w = mean(morewel_1) if east == 0 & berlin ~= 1, by(year)  //welfare should be cut, west
egen mean_morewel_2w = mean(morewel_2) if east == 0 & berlin ~= 1, by(year)  // should by kept the same
egen mean_morewel_3w = mean(morewel_3) if east == 0 & berlin ~= 1, by(year)  // should be extended
egen mean_morewel_1e = mean(morewel_1) if east == 1 & berlin ~= 1, by(year)  //welfare should be cut, east
egen mean_morewel_2e = mean(morewel_2) if east == 1 & berlin ~= 1, by(year)  // should by kept the same
egen mean_morewel_3e = mean(morewel_3) if east == 1 & berlin ~= 1, by(year)  // should be extended

replace mean_morewel_1w = mean_morewel_1w * 100  // to get proportions
replace mean_morewel_2w = mean_morewel_2w * 100  
replace mean_morewel_3w = mean_morewel_3w * 100  
replace mean_morewel_1e = mean_morewel_1e * 100  
replace mean_morewel_2e = mean_morewel_2e * 100  
replace mean_morewel_3e = mean_morewel_3e * 100  

* West
twoway (scatter mean_morewel_1w year, msymbol(circle_hollow)   mlcolor(gs6)  c(l) sort) ///
       (scatter mean_morewel_2w year, msymbol(triangle_hollow) mlcolor(gs10) c(l) sort) ///
       (scatter mean_morewel_3w year, msymbol(circle)          mlcolor(gs04) c(l) sort), ///
  legend (size(medium) label(1 "resp. in favor of decreasing") label(2 "resp. in favor of keeping") label(3 "resp. in favor of increasing"))  ///
  xlabel(1994 2000 2004 2010) xtitle("Survey Year", size(large)) title("Western Germany") ///
  name(morewel_w, replace) ylabel(0 "0%" 20"20%" 40"40%" 60"60%" 80"80%", grid angle(0))

* East
twoway (scatter mean_morewel_1e year, msymbol(circle_hollow)   mlcolor(gs6)  c(l) sort) ///
       (scatter mean_morewel_2e year, msymbol(triangle_hollow) mlcolor(gs10) c(l) sort) ///
       (scatter mean_morewel_3e year, msymbol(circle)          mlcolor(gs04) c(l) sort), ///
  legend (size(medium) label(1 "resp. in favor of decreasing") label(2 "resp. in favor of keeping") label(3 "resp. in favor of increasing"))  ///
  xlabel(1994 2000 2004 2010) xtitle("Survey Year", size(large)) title("Eastern Germany") ///
  name(morewel_e, replace) ylabel(0 "0%" 20"20%" 40"40%" 60"60%" 80"80%", grid angle(0))

grc1leg morewel_w morewel_e, legendfrom(morewel_e) saving("Figure 1_smallN", replace)


**************************************************************************************************
log close
